;;; 50xtide-el.el -- debian emacs setups for xtide-el. -*- mode: emacs-lisp -*-

;; Copyright 2009, 2012, 2014, 2015 Kevin Ryde

;; This file is part of xtide-el.
;;
;; xtide-el is free software; you can redistribute it and/or modify it under
;; the terms of the GNU General Public License as published by the Free
;; Software Foundation; either version 3, or (at your option) any later
;; version.
;;
;; xtide-el is distributed in the hope that it will be useful, but WITHOUT
;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
;; more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.


(let ((dir (concat "/usr/share/"
                   (symbol-name debian-emacs-flavor)
                   "/site-lisp/xtide-el")))

  (cond ((not (file-exists-p "/usr/share/emacs/site-lisp/xtide-el/xtide.el"))
         (message "xtide-el removed but not purged, skipping setup"))

        ((not (file-exists-p (expand-file-name "xtide.el" dir)))
         ;; autoloads not available until install script succeeds, ignore until
         ;; then for the benefit of other byte compiling, such as emacsen-common
         ;; compiling 00debian-vars.el
         (message "xtide-el not yet byte-compiled, skipping setup"))

        (t
         ;; debian-pkg-add-load-path-item as from debian 3.1 "sarge",
         ;; emacsen-common 1.4.14 of June 2002
         (debian-pkg-add-load-path-item dir)

         ;; Calendar "T" key binding enabled by default, as long as nothing
         ;; else has bound it, so a user binding or something new in
         ;; calendar.el itself isn't clobbered.
         ;;
         ;; String (eval-after-load "calendar" ...) not symbol 'calendar
         ;; here, as per notes with the menu keybinding in xtide.el, and
         ;; also because xemacs 21.4 eval-after-load doesn't accept symbols at all.
         ;;
         (eval-after-load "calendar"
           '(unless (lookup-key calendar-mode-map "T")
              (define-key calendar-mode-map "T" 'xtide-calendar-tides)))


         ;; The following autoloads generated using an eval of the following
         ;; form.  Remember to regenerate if they change.
         ;;
         ;; (load-file "my-generate-autoloads.el")

;;;### (autoloads nil "xtide" "xtide.el" (22142 19268 445452 21000))
;;; Generated autoloads from xtide.el

(let ((loads (get 'xtide 'custom-loads))) (if (member '"xtide" loads) nil (put 'xtide 'custom-loads (cons '"xtide" loads))))

(put 'xtide-location 'safe-local-variable 'stringp)

(put 'xtide-run-switches 'risky-local-variable t)

(autoload 'xtide-location-mode "xtide" "\
XTide location display and selection." nil nil)

(autoload 'xtide-location-bookmark-jump "xtide" "\
Jump to bookmark record BMK for `xtide-location-mode'." nil nil)

(autoload 'xtide "xtide" "\
Display a tides graph using XTide." t nil)

(autoload 'xtide-bookmark-jump "xtide" "\
Jump to bookmark record BMK for `xtide-mode'." nil nil)

(autoload 'xtide-calendar-tides "xtide" "\
Display tides for the calendar cursor date." t nil)

(autoload 'xtide-calendar-setups "xtide" "\
Setup xtide additions to `calendar-mode'." nil nil)

(custom-add-option 'calendar-load-hook 'xtide-calendar-setups)

(when (eval-when-compile (fboundp 'define-key-after)) (eval-after-load "calendar" '(let ((keymap (or (lookup-key calendar-mode-map [menu-bar moon]) (lookup-key calendar-mode-map [menu-bar Sun/Moon])))) (when (keymapp keymap) (define-key-after keymap [xtide] '(menu-item "Tides" xtide-calendar-tides :help "View tides for the selected day using XTide.") t)))))

(when (eval-when-compile (fboundp 'add-menu-button)) (defadvice calendar-add-menus (after xtide activate) "Add a Calendar/Tides menu entry." (add-menu-button '("Calendar") ["Tides" xtide-calendar-tides])))

;;;***


)))
